@@ -5,7 +5,10 @@ import sys
 import boto3
 import yaml
 import click
-from phlmd.model import ph_role, ph_layer, ph_lambda, ph_gateway
+from phlmd.model import ph_role
+from phlmd.model import ph_layer
+from phlmd.model import ph_lambda
+from phlmd.model import ph_gateway
 
 
 @click.group("deploy")
